# KubEasy
#### Kubernetes made easy!

### Getting Started
``` bash
brew install cdk8s
git clone git@github.com:dylanturn/kubeasy.git
cd kubeasy
pipenv install
cdk8s install

cdk8s synth
--- OR ---
pipenv run python3.8 main.py
```